import { SkyQueryableComponentHarness } from '@skyux/core/testing';
import { ComponentHarness, HarnessPredicate } from '@angular/cdk/testing';

/**
 * Harness to interact with inline form button component in tests.
 */
class SkyInlineFormButtonHarness extends ComponentHarness {
    /**
     * @internal
     */
    static { this.hostSelector = '.sky-inline-form-footer > button'; }
    /**
     * Gets a `HarnessPredicate` that can be used to search for a
     * `SkyInlineFormButtonHarness` that meets certain criteria.
     */
    static with(filters) {
        return new HarnessPredicate(SkyInlineFormButtonHarness, filters)
            .addOption('text', filters.text, async (harness, text) => {
            const harnessText = await harness.getText();
            return await HarnessPredicate.stringMatches(harnessText, text);
        })
            .addOption('styleType', filters.styleType, async (harness, styleType) => {
            const harnessStyleType = await harness.getStyleType();
            return await HarnessPredicate.stringMatches(harnessStyleType, styleType);
        });
    }
    /**
     * Clicks the button.
     */
    async click() {
        return await (await this.host()).click();
    }
    /**
     * Gets the button style type.
     */
    async getStyleType() {
        const host = await this.host();
        if (await host.hasClass('sky-btn-primary')) {
            return 'primary';
        }
        if (await host.hasClass('sky-btn-link')) {
            return 'link';
        }
        return 'default';
    }
    /**
     * Gets the button text.
     */
    async getText() {
        return await (await this.host()).text();
    }
    /**
     * Whether the button is disabled.
     */
    async isDisabled() {
        return await (await this.host()).hasClass('sky-btn-disabled');
    }
}

/**
 * Harness to interact with inline form template components in tests.
 */
class SkyInlineFormTemplateHarness extends SkyQueryableComponentHarness {
    /**
     * @internal
     */
    static { this.hostSelector = '.sky-inline-form-content'; }
}

/**
 * Harness to interact with inline form components in tests.
 */
class SkyInlineFormHarness extends SkyQueryableComponentHarness {
    /**
     * @internal
     */
    static { this.hostSelector = 'sky-inline-form'; }
    /**
     * Gets a `HarnessPredicate` that can be used to search for a
     * `SkyInlineFormHarness` that meets certain criteria.
     */
    static with(filters) {
        return SkyInlineFormHarness.getDataSkyIdPredicate(filters);
    }
    /**
     * Gets an inline form button that matches the given filters.
     */
    async getButton(filters) {
        if (!(await this.isFormExpanded())) {
            throw new Error('Inline form is not expanded. The buttons cannot be retrieved when not visible.');
        }
        return await this.locatorFor(SkyInlineFormButtonHarness.with(filters))();
    }
    /**
     * Gets the inline form's buttons.
     */
    async getButtons(filters) {
        if (!(await this.isFormExpanded())) {
            throw new Error('Inline form is not expanded. The buttons cannot be retrieved when not visible.');
        }
        const buttons = await this.locatorForAll(SkyInlineFormButtonHarness.with(filters || {}))();
        if (filters && buttons.length === 0) {
            throw new Error(`No button(s) found that match the given filter(s): ${JSON.stringify(filters)}`);
        }
        return buttons;
    }
    /**
     * Returns a harness wrapping the inline form's template when expanded.
     */
    async getTemplate() {
        if (!(await this.isFormExpanded())) {
            throw new Error('Inline form is not expanded. Cannot retrieve template when not visible.');
        }
        return await this.locatorFor(SkyInlineFormTemplateHarness)();
    }
    /**
     * Whether the inline form is shown.
     */
    async isFormExpanded() {
        return ((await (await this.host()).getAttribute('data-show-form')) === 'true');
    }
}

/**
 * Generated bundle index. Do not edit.
 */

export { SkyInlineFormButtonHarness, SkyInlineFormHarness, SkyInlineFormTemplateHarness };
//# sourceMappingURL=skyux-inline-form-testing.mjs.map
